import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useLocation } from 'react-router-dom';
import { showNotification } from '../../../store/notification.slice';
import {
    fetchPermissionsThunk,
    approvePermissionThunk,
    rejectPermissionThunk,
} from '../../../store/permissions/permissions.thunks';
import { resetOperationStatus } from '../../../store/permissions/permissions.slice';
import './PendingRequests.css'; // 引入外部CSS文件
import SvgIcon from '../../../components/SvgIcon';
import RequestDetailSlideOver from './RequestDetailSlideOver';

export default function PendingRequests() {
    const dispatch = useDispatch();
    const location = useLocation();
    const [responseMessage, setResponseMessage] = useState('');
    const [showResponseInput, setShowResponseInput] = useState(false);
    const [currentRequestId, setCurrentRequestId] = useState(null);
    const [isApproving, setIsApproving] = useState(false);
    const [selectedRequest, setSelectedRequest] = useState(null);
    const [showSlideOver, setShowSlideOver] = useState(false);

    // 从Redux store获取权限申请列表状态
    const {
        results: pendingRequests,
        status: fetchStatus,
        error: fetchError,
        page: currentPage,
        page_size: pageSize,
        total,
    } = useSelector((state) => state.permissions.pending);

    // 计算总页数
    const totalPages = Math.ceil(total / pageSize) || 1;

    // 从Redux store获取批准/拒绝操作的状态
    const {
        status: approveRejectStatus,
        error: approveRejectError,
        currentId: processingId,
    } = useSelector((state) => state.permissions.approveReject);

    // 获取待处理申请列表
    useEffect(() => {
        dispatch(fetchPermissionsThunk({ page: currentPage, page_size: pageSize }));
    }, [dispatch, currentPage, pageSize]);

    // 处理从通知中心跳转过来的请求
    useEffect(() => {
        if (location.state?.showRequestDetail) {
            const { requestId, requestData } = location.state;
            setSelectedRequest(requestData);
            setShowSlideOver(true);
            // 清除 location state
            window.history.replaceState({}, document.title);
        }
    }, [location.state]);

    // 监听批准/拒绝操作的状态变化
    useEffect(() => {
        if (approveRejectStatus === 'succeeded') {
            dispatch(
                showNotification({
                    message: isApproving ? '已批准申请' : '已拒绝申请',
                    type: 'success',
                })
            );
            setShowResponseInput(false);
            setCurrentRequestId(null);
            setResponseMessage('');
            setShowSlideOver(false);
            setSelectedRequest(null);

            // 重新获取申请列表
            dispatch(fetchPermissionsThunk({ page: currentPage, page_size: pageSize }));

            // 重置状态
            dispatch(resetOperationStatus());
        } else if (approveRejectStatus === 'failed') {
            dispatch(
                showNotification({
                    message: approveRejectError || '处理申请失败',
                    type: 'danger',
                })
            );
            // 重置状态
            dispatch(resetOperationStatus());
        }
    }, [approveRejectStatus, approveRejectError, dispatch, isApproving, currentPage, pageSize]);

    // 打开回复输入框
    const handleOpenResponseInput = (requestId, approving) => {
        setCurrentRequestId(requestId);
        setIsApproving(approving);
        setShowResponseInput(true);
    };

    // 关闭回复输入框
    const handleCloseResponseInput = () => {
        setShowResponseInput(false);
        setCurrentRequestId(null);
        setResponseMessage('');
    };

    // 处理申请（批准或拒绝）
    const handleProcessRequest = () => {
        if (!currentRequestId) return;

        const params = {
            id: currentRequestId,
            responseMessage,
        };

        if (isApproving) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 处理行点击，显示滑动面板
    const handleRowClick = (request) => {
        setSelectedRequest(request);
        setShowSlideOver(true);
    };

    // 关闭滑动面板
    const handleCloseSlideOver = () => {
        setShowSlideOver(false);
        setTimeout(() => {
            setSelectedRequest(null);
        }, 300); // 等待动画结束后再清除选中的申请
    };

    // 直接处理申请（不显示弹窗）
    const handleDirectProcess = (requestId, approve) => {
        setCurrentRequestId(requestId);
        setIsApproving(approve);

        const params = {
            id: requestId,
            responseMessage: approve ? '已批准' : '已拒绝',
        };

        if (approve) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 处理页码变化
    const handlePageChange = (page) => {
        dispatch(fetchPermissionsThunk({ page, page_size: pageSize }));
    };

    // 渲染分页控件
    const renderPagination = () => {
        if (totalPages <= 1) return null;

        return (
            <div className='pagination-container'>
                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage - 1)}
                    disabled={currentPage === 1}
                >
                    上一页
                </button>

                <div className='pagination-info'>
                    {currentPage} / {totalPages}
                </div>

                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage + 1)}
                    disabled={currentPage === totalPages}
                >
                    下一页
                </button>
            </div>
        );
    };

    // 渲染加载状态
    if (fetchStatus === 'loading' && pendingRequests.length === 0) {
        return (
            <div className='text-center py-5'>
                <div className='spinner-border' role='status'>
                    <span className='visually-hidden'>加载中...</span>
                </div>
                <p className='mt-3'>加载待处理申请...</p>
            </div>
        );
    }

    // 渲染错误状态
    if (fetchStatus === 'failed' && pendingRequests.length === 0) {
        return (
            <div className='alert alert-danger' role='alert'>
                {fetchError || '获取待处理申请失败'}
            </div>
        );
    }

    // 渲染空状态
    if (pendingRequests.length === 0) {
        return (
            <div className='alert alert-info' role='alert'>
                暂无待处理的权限申请
            </div>
        );
    }

    // 渲染申请列表
    return (
        <>
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <h5 className='mb-0'>待处理申请</h5>
                <div className='badge bg-danger'>{total}个待处理</div>
            </div>

            <div className='pending-requests-list'>
                {pendingRequests.map((request) => (
                    <div key={request.id} className='pending-request-item' onClick={() => handleRowClick(request)}>
                        <div className='request-header'>
                            <div className='user-info'>
                                <h6 className='mb-0'>{request.applicant.name || request.applicant.username}</h6>
                                <small className='text-muted'>{request.applicant.department || '未分配部门'}</small>
                            </div>
                            <div className='request-date'>{new Date(request.created_at).toLocaleDateString()}</div>
                        </div>

                        <div className='request-content'>
                            <p className='mb-2'>申请访问：{request.knowledge_base.name}</p>

                            {request.permissions.can_edit ? (
                                <span
                                    className='badge bg-success-subtle text-success d-flex align-items-center gap-1'
                                    style={{ width: 'fit-content' }}
                                >
                                    <SvgIcon className={'circle-yes'} />
                                    完全访问
                                </span>
                            ) : (
                                request.permissions.can_read && (
                                    <span
                                        className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'
                                        style={{ width: 'fit-content' }}
                                    >
                                        <SvgIcon className={'eye'} />
                                        只读访问
                                    </span>
                                )
                            )}

                            {request.expires_at && (
                                <div className='mt-2'>
                                    <small className='text-muted'>
                                        到期时间: {new Date(request.expires_at).toLocaleDateString()}
                                    </small>
                                </div>
                            )}
                        </div>
                        <div className='request-actions'>
                            <button
                                className='btn btn-outline-danger btn-sm'
                                onClick={(e) => {
                                    e.stopPropagation();
                                    handleDirectProcess(request.id, false);
                                }}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && !isApproving
                                    ? '处理中...'
                                    : '拒绝'}
                            </button>
                            <button
                                className='btn btn-outline-success btn-sm'
                                onClick={(e) => {
                                    e.stopPropagation();
                                    handleDirectProcess(request.id, true);
                                }}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && isApproving
                                    ? '处理中...'
                                    : '批准'}
                            </button>
                        </div>
                    </div>
                ))}
            </div>

            {/* 分页控件 */}
            {renderPagination()}

            {/* 使用新的滑动面板组件 */}
            <RequestDetailSlideOver
                show={showSlideOver}
                onClose={handleCloseSlideOver}
                request={selectedRequest}
                onApprove={(id) => handleOpenResponseInput(id, true)}
                onReject={(id) => handleOpenResponseInput(id, false)}
                processingId={processingId}
                approveRejectStatus={approveRejectStatus}
                isApproving={isApproving}
            />

            {/* 回复输入弹窗 */}
            {showResponseInput && (
                <div className='modal fade show' style={{ display: 'block' }} tabIndex='-1'>
                    <div className='modal-dialog' style={{ zIndex: 9999 }}>
                        <div className='modal-content'>
                            <div className='modal-header'>
                                <h5 className='modal-title'>{isApproving ? '批准' : '拒绝'}申请</h5>
                                <button
                                    type='button'
                                    className='btn-close'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                ></button>
                            </div>
                            <div className='modal-body'>
                                <div className='mb-3'>
                                    <label htmlFor='responseMessage' className='form-label'>
                                        审批意见
                                    </label>
                                    <textarea
                                        className='form-control'
                                        id='responseMessage'
                                        rows='3'
                                        value={responseMessage}
                                        onChange={(e) => setResponseMessage(e.target.value)}
                                        placeholder={isApproving ? '请输入批准意见（可选）' : '请输入拒绝理由（可选）'}
                                    ></textarea>
                                </div>
                            </div>
                            <div className='modal-footer'>
                                <button
                                    type='button'
                                    className='btn btn-secondary'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    取消
                                </button>
                                <button
                                    type='button'
                                    className={`btn ${isApproving ? 'btn-success' : 'btn-danger'}`}
                                    onClick={handleProcessRequest}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    {approveRejectStatus === 'loading' ? (
                                        <>
                                            <span
                                                className='spinner-border spinner-border-sm me-1'
                                                role='status'
                                                aria-hidden='true'
                                            ></span>
                                            处理中...
                                        </>
                                    ) : isApproving ? (
                                        '确认批准'
                                    ) : (
                                        '确认拒绝'
                                    )}
                                </button>
                            </div>
                        </div>
                    </div>
                    <div className='modal-backdrop fade show'></div>
                </div>
            )}
        </>
    );
}
