import React, { useState, useEffect } from 'react';
import { get, post } from '../../../services/api';

export default function UserPermissionDetails({ user, onClose, onSave }) {
    const [updatedPermissions, setUpdatedPermissions] = useState({});
    const [userPermissions, setUserPermissions] = useState([]);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);
    const [savingPermissions, setSavingPermissions] = useState(false);
    const [successMessage, setSuccessMessage] = useState(null);

    useEffect(() => {
        // If we already have the permissions data in the user object, use it
        if (user.permissions && Array.isArray(user.permissions)) {
            setUserPermissions(user.permissions);
            setLoading(false);
        } else {
            // Otherwise fetch the detailed permissions
            fetchUserPermissions();
        }
    }, [user]);

    const fetchUserPermissions = async () => {
        setLoading(true);
        try {
            const response = await get(`/api/users/${user.user_info.id}/permissions`);
            setUserPermissions(response.permissions || []);
            setError(null);
        } catch (err) {
            setError('获取用户权限详情失败: ' + (err.message || '未知错误'));
        } finally {
            setLoading(false);
        }
    };

    const handlePermissionChange = (knowledgeBaseId, newPermissionType) => {
        setUpdatedPermissions((prev) => ({
            ...prev,
            [knowledgeBaseId]: newPermissionType,
        }));
    };

    const handleSave = async () => {
        setSavingPermissions(true);
        setError(null);
        setSuccessMessage(null);

        try {
            const permissionUpdates = Object.entries(updatedPermissions).map(
                async ([knowledgeBaseId, permissionType]) => {
                    const permissions = {
                        can_read: permissionType !== 'none',
                        can_edit: ['edit', 'admin'].includes(permissionType),
                        can_delete: permissionType === 'admin',
                    };

                    const requestBody = {
                        user_id: user.user_info.id,
                        knowledge_base_id: knowledgeBaseId,
                        permissions: permissions,
                        // Optional expiration date - can be added if needed
                        // expires_at: "2025-12-31T23:59:59Z"
                    };

                    try {
                        const response = await post('/permissions/update_permission/', requestBody);
                        return response;
                    } catch (err) {
                        throw new Error(`更新知识库 ${knowledgeBaseId} 权限失败: ${err.message || '未知错误'}`);
                    }
                }
            );

            await Promise.all(permissionUpdates);

            setSuccessMessage('权限更新成功');
            // Refresh permissions list
            fetchUserPermissions();
            // Reset updated permissions
            setUpdatedPermissions({});

            // Notify parent component if needed
            if (onSave) {
                onSave(user.user_info.id);
            }
        } catch (err) {
            setError(err.message || '更新权限时发生错误');
        } finally {
            setSavingPermissions(false);
        }
    };

    // 获取权限类型的显示文本
    const getPermissionTypeText = (permissionType) => {
        switch (permissionType) {
            case 'none':
                return '无权限';
            case 'read':
                return '只读访问';
            case 'edit':
                return '编辑权限';
            case 'admin':
                return '管理权限';
            default:
                return '未知权限';
        }
    };

    // 获取权限类型的值
    const getPermissionType = (permission) => {
        if (!permission) return 'none';
        if (permission.can_delete) return 'admin';
        if (permission.can_edit) return 'edit';
        if (permission.can_read) return 'read';
        return 'none';
    };

    return (
        <div className='modal fade show' style={{ display: 'block' }} tabIndex='-1'>
            <div className='modal-dialog modal-lg modal-dialog-scrollable' style={{ zIndex: 9999 }}>
                <div className='modal-content'>
                    <div className='modal-header'>
                        <h5 className='modal-title'>{user.user_info.name} 的权限详情</h5>
                        <button type='button' className='btn-close' onClick={onClose}></button>
                    </div>
                    <div className='modal-body'>
                        {successMessage && (
                            <div className='alert alert-success alert-dismissible fade show' role='alert'>
                                {successMessage}
                                <button
                                    type='button'
                                    className='btn-close'
                                    onClick={() => setSuccessMessage(null)}
                                ></button>
                            </div>
                        )}

                        {loading ? (
                            <div className='text-center py-4'>
                                <div className='spinner-border' role='status'>
                                    <span className='visually-hidden'>加载中...</span>
                                </div>
                                <p className='mt-3'>加载权限详情...</p>
                            </div>
                        ) : error ? (
                            <div>
                                <div className='alert alert-warning' role='alert'>
                                    {error}
                                </div>
                                {userPermissions.length > 0 && (
                                    <div className='table-responsive'>
                                        <table className='table table-hover'>
                                            <thead className='table-light'>
                                                <tr>
                                                    <th>知识库名称</th>
                                                    <th>所属部门</th>
                                                    <th>当前权限</th>
                                                    <th>最后访问时间</th>
                                                    <th>操作</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                {userPermissions.map((item) => {
                                                    const currentPermissionType = getPermissionType(item.permissions);
                                                    const updatedPermissionType =
                                                        updatedPermissions[item.knowledge_base.id] ||
                                                        currentPermissionType;

                                                    return (
                                                        <tr key={item.knowledge_base.id}>
                                                            <td>{item.knowledge_base.name}</td>
                                                            <td>{item.knowledge_base.department || '未指定'}</td>
                                                            <td>
                                                                <span
                                                                    className={`badge ${
                                                                        currentPermissionType === 'admin'
                                                                            ? 'bg-danger'
                                                                            : currentPermissionType === 'edit'
                                                                            ? 'bg-success'
                                                                            : currentPermissionType === 'read'
                                                                            ? 'bg-info'
                                                                            : 'bg-secondary'
                                                                    }`}
                                                                >
                                                                    {getPermissionTypeText(currentPermissionType)}
                                                                </span>
                                                            </td>
                                                            <td>
                                                                {item.granted_at
                                                                    ? new Date(item.granted_at).toLocaleString()
                                                                    : '从未访问'}
                                                            </td>
                                                            <td>
                                                                <select
                                                                    className='form-select form-select-sm'
                                                                    value={updatedPermissionType}
                                                                    onChange={(e) =>
                                                                        handlePermissionChange(
                                                                            item.knowledge_base.id,
                                                                            e.target.value
                                                                        )
                                                                    }
                                                                >
                                                                    <option value='none'>无权限</option>
                                                                    <option value='read'>只读访问</option>
                                                                    <option value='edit'>编辑权限</option>
                                                                    <option value='admin'>管理权限</option>
                                                                </select>
                                                            </td>
                                                        </tr>
                                                    );
                                                })}
                                            </tbody>
                                        </table>
                                    </div>
                                )}
                            </div>
                        ) : userPermissions.length === 0 ? (
                            <div className='alert alert-info' role='alert'>
                                该用户暂无任何知识库权限
                            </div>
                        ) : (
                            <div className='table-responsive'>
                                <table className='table table-hover'>
                                    <thead className='table-light'>
                                        <tr>
                                            <th>知识库名称</th>
                                            <th>所属部门</th>
                                            <th>当前权限</th>
                                            <th>授权时间</th>
                                            <th>操作</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        {userPermissions.map((item) => {
                                            const currentPermissionType = getPermissionType(item.permissions);
                                            const updatedPermissionType =
                                                updatedPermissions[item.knowledge_base.id] || currentPermissionType;

                                            return (
                                                <tr key={item.knowledge_base.id}>
                                                    <td>{item.knowledge_base.name}</td>
                                                    <td>{item.knowledge_base.department || '未指定'}</td>
                                                    <td>
                                                        <span
                                                            className={`badge ${
                                                                currentPermissionType === 'admin'
                                                                    ? 'bg-danger'
                                                                    : currentPermissionType === 'edit'
                                                                    ? 'bg-success'
                                                                    : currentPermissionType === 'read'
                                                                    ? 'bg-info'
                                                                    : 'bg-secondary'
                                                            }`}
                                                        >
                                                            {getPermissionTypeText(currentPermissionType)}
                                                        </span>
                                                    </td>
                                                    <td>
                                                        {item.granted_at
                                                            ? new Date(item.granted_at).toLocaleString()
                                                            : '未记录'}
                                                    </td>
                                                    <td>
                                                        <select
                                                            className='form-select form-select-sm'
                                                            value={updatedPermissionType}
                                                            onChange={(e) =>
                                                                handlePermissionChange(
                                                                    item.knowledge_base.id,
                                                                    e.target.value
                                                                )
                                                            }
                                                        >
                                                            <option value='none'>无权限</option>
                                                            <option value='read'>只读访问</option>
                                                            <option value='edit'>编辑权限</option>
                                                            <option value='admin'>管理权限</option>
                                                        </select>
                                                    </td>
                                                </tr>
                                            );
                                        })}
                                    </tbody>
                                </table>
                            </div>
                        )}
                    </div>
                    <div className='modal-footer'>
                        <button type='button' className='btn btn-secondary' onClick={onClose}>
                            关闭
                        </button>
                        <button
                            type='button'
                            className='btn btn-dark'
                            onClick={handleSave}
                            disabled={loading || savingPermissions || Object.keys(updatedPermissions).length === 0}
                        >
                            {savingPermissions ? (
                                <>
                                    <span
                                        className='spinner-border spinner-border-sm me-2'
                                        role='status'
                                        aria-hidden='true'
                                    ></span>
                                    保存中...
                                </>
                            ) : (
                                '保存更改'
                            )}
                        </button>
                    </div>
                </div>
            </div>
            <div className='modal-backdrop fade show' style={{ zIndex: 1050 }}></div>
        </div>
    );
}
