import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { fetchAllUserPermissions, updateUserPermissions } from '../../../store/permissions/permissions.thunks';
import UserPermissionDetails from './UserPermissionDetails';
import './UserPermissions.css';
import SvgIcon from '../../../components/SvgIcon';

// 每页显示选项
const PAGE_SIZE_OPTIONS = [5, 10, 15, 20, 50, 100];

export default function UserPermissions() {
    const dispatch = useDispatch();
    const [selectedUser, setSelectedUser] = useState(null);
    const [showDetailsModal, setShowDetailsModal] = useState(false);
    const [searchTerm, setSearchTerm] = useState('');

    // 分页状态
    const [currentPage, setCurrentPage] = useState(1);
    const [pageSize, setPageSize] = useState(10);

    // 从 Redux store 获取用户列表和状态
    const {
        results: users,
        status: loading,
        error,
        total,
        page,
        page_size,
    } = useSelector((state) => state.permissions.allUsersPermissions);

    // 获取用户列表
    useEffect(() => {
        dispatch(fetchAllUserPermissions({ page: currentPage, page_size: pageSize }));
    }, [dispatch, currentPage, pageSize]);

    // 计算总页数
    const totalPages = Math.ceil(total / page_size);

    const handleOpenDetailsModal = (data) => {
        setSelectedUser(data);
        setShowDetailsModal(true);
    };

    const handleCloseDetailsModal = () => {
        setSelectedUser(null);
        setShowDetailsModal(false);
    };

    const handleSavePermissions = async (userId) => {
        try {
            // Permission updates are now handled directly in the UserPermissionDetails component
            // Just refresh the users list to reflect the updated permissions
            handleCloseDetailsModal();
            dispatch(fetchAllUserPermissions({ page: currentPage, page_size: pageSize }));
        } catch (error) {
            console.error('更新权限失败:', error);
        }
    };

    const handleSearchChange = (e) => {
        setSearchTerm(e.target.value);
        setCurrentPage(1); // 重置到第一页
    };

    const handlePageChange = (page) => {
        if (page > 0 && page <= totalPages) {
            setCurrentPage(page);
        }
    };

    const handlePageSizeChange = (e) => {
        const newPageSize = parseInt(e.target.value);
        setPageSize(newPageSize);
        setCurrentPage(1); // 重置到第一页
    };

    // 过滤用户列表
    const getFilteredUsers = () => {
        if (!searchTerm.trim()) {
            return users;
        }

        return users.filter(
            (user) =>
                user.user_info?.username.toLowerCase().includes(searchTerm.toLowerCase()) ||
                user.user_info?.name.toLowerCase().includes(searchTerm.toLowerCase()) ||
                user.user_info?.department.toLowerCase().includes(searchTerm.toLowerCase()) ||
                user.user_info?.role.toLowerCase().includes(searchTerm.toLowerCase())
        );
    };

    const filteredUsers = getFilteredUsers();

    const renderPagination = () => {
        const pageNumbers = [];
        const ellipsis = (
            <li className='page-item disabled' key='ellipsis'>
                <span className='page-link'>...</span>
            </li>
        );

        let startPage = Math.max(1, currentPage - 2);
        let endPage = Math.min(totalPages, startPage + 4);

        if (endPage - startPage < 4) {
            startPage = Math.max(1, endPage - 4);
        }

        // 总是显示第一页
        if (startPage > 1) {
            pageNumbers.push(
                <li className={`page-item`} key={1}>
                    <button className='page-link' onClick={() => handlePageChange(1)}>
                        1
                    </button>
                </li>
            );

            // 如果第一页和起始页之间有间隔，显示省略号
            if (startPage > 2) {
                pageNumbers.push(ellipsis);
            }
        }

        // 添加页码按钮
        for (let i = startPage; i <= endPage; i++) {
            pageNumbers.push(
                <li className={`page-item ${i === currentPage ? 'active' : ''}`} key={i}>
                    <button className='page-link' onClick={() => handlePageChange(i)}>
                        {i}
                    </button>
                </li>
            );
        }

        // 如果末页和最后一页之间有间隔，显示省略号
        if (endPage < totalPages - 1) {
            pageNumbers.push(ellipsis);
        }

        // 如果末页不是最后一页，显示最后一页
        if (endPage < totalPages) {
            pageNumbers.push(
                <li className={`page-item`} key={totalPages}>
                    <button className='page-link' onClick={() => handlePageChange(totalPages)}>
                        {totalPages}
                    </button>
                </li>
            );
        }

        return (
            <div className='d-flex justify-content-between align-items-center my-3'>
                <div className='d-flex align-items-center'>
                    <span className='me-2'>每页显示:</span>
                    <select
                        className='form-select form-select-sm'
                        value={pageSize}
                        onChange={handlePageSizeChange}
                        style={{ width: 'auto' }}
                    >
                        {PAGE_SIZE_OPTIONS.map((size) => (
                            <option key={size} value={size}>
                                {size}
                            </option>
                        ))}
                    </select>
                    <span className='ms-3'>
                        总计 <strong>{total}</strong> 条记录
                    </span>
                </div>

                <nav aria-label='Page navigation'>
                    <ul className='pagination mb-0 dark-pagination'>
                        <li className={`page-item ${currentPage === 1 ? 'disabled' : ''}`}>
                            <button className='page-link' onClick={() => handlePageChange(currentPage - 1)}>
                                上一页
                            </button>
                        </li>
                        {pageNumbers}
                        <li className={`page-item ${currentPage === totalPages ? 'disabled' : ''}`}>
                            <button className='page-link' onClick={() => handlePageChange(currentPage + 1)}>
                                下一页
                            </button>
                        </li>
                    </ul>
                </nav>
            </div>
        );
    };

    return (
        <>
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <h5 className='mb-0'>用户权限管理</h5>
            </div>

            <>
                {/* <div className='mb-3 d-flex justify-content-between align-items-center'>
                    <div className='search-bar' style={{ maxWidth: '300px' }}>
                        <div className='input-group'>
                            <span className='input-group-text bg-light border-end-0'>
                                <SvgIcon className='search' />
                            </span>
                            <input
                                type='text'
                                className='form-control border-start-0'
                                placeholder='搜索用户...'
                                value={searchTerm}
                                onChange={handleSearchChange}
                            />
                        </div>
                    </div>
                </div> */}

                {loading === 'loading' ? (
                    <div className='text-center my-5'>
                        <div className='spinner-border text-primary' role='status'>
                            <span className='visually-hidden'>加载中...</span>
                        </div>
                        <p className='mt-2'>加载用户权限列表...</p>
                    </div>
                ) : error ? (
                    <div className='alert alert-danger' role='alert'>
                        {error}
                    </div>
                ) : (
                    <>
                        <div className='table-responsive'>
                            <table className='table table-hover'>
                                <thead className='table-light'>
                                    <tr>
                                        <th>ID</th>
                                        <th>用户名</th>
                                        <th>姓名</th>
                                        <th>部门</th>
                                        <th>角色</th>
                                        <th>权限类型</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    {filteredUsers.length > 0 ? (
                                        filteredUsers.map((userPermission) => (
                                            <tr key={userPermission.user_info?.id}>
                                                <td className='align-middle'>{userPermission.user_info?.id}</td>
                                                <td className='align-middle'>
                                                    {userPermission.user_info?.username || 'N/A'}
                                                </td>
                                                <td className='align-middle'>
                                                    {userPermission.user_info?.name || 'N/A'}
                                                </td>
                                                <td className='align-middle'>
                                                    {userPermission.user_info?.department || 'N/A'}
                                                </td>
                                                <td className='align-middle'>
                                                    <span
                                                        className={`badge ${
                                                            userPermission.user_info?.role === 'admin'
                                                                ? 'bg-danger-subtle text-danger'
                                                                : userPermission.user_info?.role === 'leader'
                                                                ? 'bg-warning-subtle text-warning'
                                                                : 'bg-info-subtle text-info'
                                                        }`}
                                                    >
                                                        {userPermission.user_info?.role === 'admin'
                                                            ? '管理员'
                                                            : userPermission.user_info?.role === 'leader'
                                                            ? '组长'
                                                            : '成员'}
                                                    </span>
                                                </td>
                                                <td className='align-middle'>
                                                    <div className='d-flex flex-wrap gap-1'>
                                                        {userPermission.stats?.by_permission?.full_access > 0 && (
                                                            <span
                                                                className='badge 
                                                                    bg-success-subtle text-success 
                                                                    d-flex align-items-center gap-1'
                                                            >
                                                                完全访问:{' '}
                                                                {userPermission.stats?.by_permission?.full_access}
                                                            </span>
                                                        )}

                                                        {userPermission.stats?.by_permission?.read_only > 0 && (
                                                            <span
                                                                className='badge 
                                                                    bg-warning-subtle text-warning 
                                                                    d-flex align-items-center gap-1'
                                                            >
                                                                只读访问:{' '}
                                                                {userPermission.stats?.by_permission?.read_only}
                                                            </span>
                                                        )}

                                                        {userPermission.stats?.by_permission?.read_write > 0 && (
                                                            <span
                                                                className='badge 
                                                                    bg-info-subtle text-info 
                                                                    d-flex align-items-center gap-1'
                                                            >
                                                                读写权限:{' '}
                                                                {userPermission.stats?.by_permission?.read_write}
                                                            </span>
                                                        )}
                                                    </div>
                                                </td>
                                                <td className='align-middle'>
                                                    <button
                                                        className='btn btn-sm btn-outline-dark'
                                                        onClick={() => handleOpenDetailsModal(userPermission)}
                                                    >
                                                        查看权限
                                                    </button>
                                                </td>
                                            </tr>
                                        ))
                                    ) : (
                                        <tr>
                                            <td colSpan='7' className='text-center py-4'>
                                                无匹配的用户记录
                                            </td>
                                        </tr>
                                    )}
                                </tbody>
                            </table>
                        </div>

                        {totalPages > 1 && renderPagination()}
                    </>
                )}

                {showDetailsModal && selectedUser && (
                    <UserPermissionDetails
                        user={selectedUser}
                        onClose={handleCloseDetailsModal}
                        onSave={handleSavePermissions}
                    />
                )}
            </>
        </>
    );
}
