import React, { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { Link, useNavigate } from 'react-router-dom';
import { checkAuthThunk, loginThunk } from '../../store/auth/auth.thunk';
import { showNotification } from '../../store/notification.slice';

export default function Login() {
    const dispatch = useDispatch();
    const navigate = useNavigate();
    const [username, setUsername] = useState('leader2');
    const [password, setPassword] = useState('leader123');
    const [errors, setErrors] = useState({});
    const [submitted, setSubmitted] = useState(false);
    const [isLoading, setIsLoading] = useState(false);

    const { user } = useSelector((state) => state.auth);

    useEffect(() => {
        handleCheckAuth();
    }, [dispatch]);

    const handleCheckAuth = async () => {
        console.log('login page handleCheckAuth');
        try {
            await dispatch(checkAuthThunk()).unwrap();
            if (user) navigate('/');
        } catch (error) {
            // 检查登录状态失败，不需要显示通知
        }
    };

    const validateForm = () => {
        const newErrors = {};
        if (!username) {
            newErrors.username = '请输入用户名';
        }
        if (!password) {
            newErrors.password = '请输入密码';
        } else if (password.length < 6) {
            newErrors.password = '密码长度不能少于6个字符';
        }
        setErrors(newErrors);
        return Object.keys(newErrors).length === 0;
    };

    const handleSubmit = async (e) => {
        e.preventDefault();
        setSubmitted(true);

        if (validateForm()) {
            setIsLoading(true);
            try {
                await dispatch(loginThunk({ username, password })).unwrap();
                navigate('/');
            } catch (error) {
                // 登录失败的错误通知已在thunk中处理
                console.error('Login failed:', error);
            } finally {
                setIsLoading(false);
            }
        }
    };

    return (
        <div className='position-absolute top-50 start-50 translate-middle d-flex flex-column gap-4 align-items-center'>
            <div className='title text-center h1'>OOIN 智能知识库</div>
            <form
                className='auth-form login-form d-flex flex-column gap-3 align-items-center'
                onSubmit={handleSubmit}
                noValidate
            >
                <div className='input-group has-validation'>
                    <input
                        value={username}
                        type='text'
                        className={`form-control form-control-lg${submitted && errors.username ? ' is-invalid' : ''}`}
                        id='username'
                        placeholder='用户名'
                        required
                        onChange={(e) => setUsername(e.target.value.trim())}
                    ></input>
                    {submitted && errors.username && <div className='invalid-feedback'>{errors.username}</div>}
                </div>
                <div className='input-group has-validation'>
                    <input
                        value={password}
                        type='password'
                        id='password'
                        placeholder='密码'
                        required
                        className={`form-control form-control-lg${submitted && errors.password ? ' is-invalid' : ''}`}
                        aria-describedby='passwordHelpBlock'
                        onChange={(e) => setPassword(e.target.value.trim())}
                    ></input>
                    {submitted && errors.password && <div className='invalid-feedback'>{errors.password}</div>}
                </div>
                <Link to='#' className='find-password text-body-secondary'>
                    忘记密码?
                </Link>
                <button type='submit' className='btn btn-dark btn-lg w-100' disabled={isLoading}>
                    {isLoading ? (
                        <>
                            <span
                                className='spinner-border spinner-border-sm me-2'
                                role='status'
                                aria-hidden='true'
                            ></span>
                            登录中...
                        </>
                    ) : (
                        '登录'
                    )}
                </button>
            </form>
            <Link to='/signup' className='go-to-signup w-100 link-underline-light h5 text-center'>
                没有账号？去注册
            </Link>
        </div>
    );
}
