import { createSlice } from '@reduxjs/toolkit';
import {
    fetchAvailableDatasets,
    fetchChats,
    createChat,
    updateChat,
    deleteChat,
    createChatRecord,
    fetchConversationDetail,
} from './chat.thunks';
import { fetchMessages, sendMessage } from './chat.messages.thunks';

// 初始状态
const initialState = {
    // Chat history state
    history: {
        items: [],
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
    },
    // Chat session creation state
    createSession: {
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
        sessionId: null,
    },
    // Chat messages state
    messages: {
        items: [],
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
    },
    // Send message state
    sendMessage: {
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
    },
    // 可用于聊天的知识库列表
    availableDatasets: {
        items: [],
        status: 'idle',
        error: null,
    },
    // 操作状态（创建、更新、删除）
    operations: {
        status: 'idle', // 'idle' | 'loading' | 'succeeded' | 'failed'
        error: null,
    },
    // 兼容旧版本的state结构
    list: {
        items: [],
        total: 0,
        page: 1,
        page_size: 10,
        status: 'idle',
        error: null,
    },
    // 当前聊天
    currentChat: {
        data: null,
        status: 'idle',
        error: null,
    },
};

// 创建 slice
const chatSlice = createSlice({
    name: 'chat',
    initialState,
    reducers: {
        // 重置操作状态
        resetOperationStatus: (state) => {
            state.operations.status = 'idle';
            state.operations.error = null;
        },

        // 重置当前聊天
        resetCurrentChat: (state) => {
            state.currentChat.data = null;
            state.currentChat.status = 'idle';
            state.currentChat.error = null;
        },

        // 设置当前聊天
        setCurrentChat: (state, action) => {
            state.currentChat.data = action.payload;
            state.currentChat.status = 'succeeded';
        },

        // 重置消息状态
        resetMessages: (state) => {
            state.messages.items = [];
            state.messages.status = 'idle';
            state.messages.error = null;
        },

        // 重置发送消息状态
        resetSendMessageStatus: (state) => {
            state.sendMessage.status = 'idle';
            state.sendMessage.error = null;
        },

        // 添加消息
        addMessage: (state, action) => {
            state.messages.items.push(action.payload);
        },
    },
    extraReducers: (builder) => {
        // 获取聊天列表
        builder
            .addCase(fetchChats.pending, (state) => {
                state.list.status = 'loading';
                state.history.status = 'loading';
            })
            .addCase(fetchChats.fulfilled, (state, action) => {
                state.list.status = 'succeeded';
                state.list.items = action.payload.results;
                state.list.total = action.payload.total;
                state.list.page = action.payload.page;
                state.list.page_size = action.payload.page_size;

                // 同时更新新的状态结构
                state.history.status = 'succeeded';
                state.history.items = action.payload.results;
                state.history.error = null;
            })
            .addCase(fetchChats.rejected, (state, action) => {
                state.list.status = 'failed';
                state.list.error = action.payload || action.error.message;

                // 同时更新新的状态结构
                state.history.status = 'failed';
                state.history.error = action.payload || action.error.message;
            })

            // 创建聊天
            .addCase(createChat.pending, (state) => {
                state.operations.status = 'loading';
            })
            .addCase(createChat.fulfilled, (state, action) => {
                state.operations.status = 'succeeded';
                state.list.items.unshift(action.payload);
                state.list.total += 1;
                state.currentChat.data = action.payload;
                state.currentChat.status = 'succeeded';
            })
            .addCase(createChat.rejected, (state, action) => {
                state.operations.status = 'failed';
                state.operations.error = action.payload || action.error.message;
            })

            // 删除聊天
            .addCase(deleteChat.pending, (state) => {
                state.operations.status = 'loading';
            })
            .addCase(deleteChat.fulfilled, (state, action) => {
                state.operations.status = 'succeeded';
                // 更新旧的状态结构
                state.list.items = state.list.items.filter((chat) => chat.id !== action.payload);
                // 更新新的状态结构
                state.history.items = state.history.items.filter((chat) => chat.conversation_id !== action.payload);

                if (state.list.total > 0) {
                    state.list.total -= 1;
                }

                if (state.currentChat.data && state.currentChat.data.id === action.payload) {
                    state.currentChat.data = null;
                }
            })
            .addCase(deleteChat.rejected, (state, action) => {
                state.operations.status = 'failed';
                state.operations.error = action.payload || action.error.message;
            })

            // 更新聊天
            .addCase(updateChat.pending, (state) => {
                state.operations.status = 'loading';
            })
            .addCase(updateChat.fulfilled, (state, action) => {
                state.operations.status = 'succeeded';
                const index = state.list.items.findIndex((chat) => chat.id === action.payload.id);
                if (index !== -1) {
                    state.list.items[index] = action.payload;
                }
                if (state.currentChat.data && state.currentChat.data.id === action.payload.id) {
                    state.currentChat.data = action.payload;
                }
            })
            .addCase(updateChat.rejected, (state, action) => {
                state.operations.status = 'failed';
                state.operations.error = action.payload || action.error.message;
            })

            // 获取聊天消息
            .addCase(fetchMessages.pending, (state) => {
                state.messages.status = 'loading';
                state.messages.error = null;
            })
            .addCase(fetchMessages.fulfilled, (state, action) => {
                state.messages.status = 'succeeded';
                state.messages.items = action.payload;
            })
            .addCase(fetchMessages.rejected, (state, action) => {
                state.messages.status = 'failed';
                state.messages.error = action.error.message;
            })

            // 发送聊天消息
            .addCase(sendMessage.pending, (state) => {
                state.sendMessage.status = 'loading';
                state.sendMessage.error = null;
            })
            .addCase(sendMessage.fulfilled, (state, action) => {
                state.sendMessage.status = 'succeeded';
                // 更新消息列表
                const index = state.messages.items.findIndex(
                    (msg) => msg.content === action.payload.content && msg.sender === action.payload.sender
                );
                if (index === -1) {
                    state.messages.items.push(action.payload);
                }
            })
            .addCase(sendMessage.rejected, (state, action) => {
                state.sendMessage.status = 'failed';
                state.sendMessage.error = action.error.message;
            })

            // 处理创建聊天记录
            .addCase(createChatRecord.pending, (state) => {
                state.sendMessage.status = 'loading';
                state.sendMessage.error = null;
            })
            .addCase(createChatRecord.fulfilled, (state, action) => {
                state.sendMessage.status = 'succeeded';
                // 添加新的消息
                state.messages.items.push({
                    id: action.payload.id,
                    role: 'user',
                    content: action.meta.arg.question,
                    created_at: new Date().toISOString(),
                });

                // 添加助手回复
                if (action.payload.role === 'assistant' && action.payload.content) {
                    state.messages.items.push({
                        id: action.payload.id,
                        role: 'assistant',
                        content: action.payload.content,
                        created_at: action.payload.created_at,
                    });
                }

                // 更新聊天记录列表
                const chatExists = state.history.items.some(
                    (chat) => chat.conversation_id === action.payload.conversation_id
                );

                if (!chatExists) {
                    const newChat = {
                        conversation_id: action.payload.conversation_id,
                        last_message: action.payload.content,
                        last_time: action.payload.created_at,
                        datasets: [
                            {
                                id: action.payload.dataset_id,
                                name: action.payload.dataset_name,
                            },
                        ],
                        dataset_id_list: action.payload.dataset_id_list,
                        message_count: 2, // 用户问题和助手回复
                    };

                    state.history.items.unshift(newChat);
                } else {
                    // 更新已存在聊天的最后消息和时间
                    const chatIndex = state.history.items.findIndex(
                        (chat) => chat.conversation_id === action.payload.conversation_id
                    );

                    if (chatIndex !== -1) {
                        state.history.items[chatIndex].last_message = action.payload.content;
                        state.history.items[chatIndex].last_time = action.payload.created_at;
                        state.history.items[chatIndex].message_count += 2; // 新增用户问题和助手回复
                    }
                }
            })
            .addCase(createChatRecord.rejected, (state, action) => {
                state.sendMessage.status = 'failed';
                state.sendMessage.error = action.payload || '创建聊天记录失败';
            })

            // 处理获取可用知识库
            .addCase(fetchAvailableDatasets.pending, (state) => {
                state.availableDatasets.status = 'loading';
                state.availableDatasets.error = null;
            })
            .addCase(fetchAvailableDatasets.fulfilled, (state, action) => {
                state.availableDatasets.status = 'succeeded';
                state.availableDatasets.items = action.payload || [];
                state.availableDatasets.error = null;
            })
            .addCase(fetchAvailableDatasets.rejected, (state, action) => {
                state.availableDatasets.status = 'failed';
                state.availableDatasets.error = action.payload || '获取可用知识库失败';
            })

            // 获取会话详情
            .addCase(fetchConversationDetail.pending, (state) => {
                state.currentChat.status = 'loading';
                state.currentChat.error = null;
            })
            .addCase(fetchConversationDetail.fulfilled, (state, action) => {
                if (action.payload) {
                    state.currentChat.status = 'succeeded';
                    state.currentChat.data = action.payload;
                } else {
                    state.currentChat.status = 'idle';
                    state.currentChat.data = null;
                }
            })
            .addCase(fetchConversationDetail.rejected, (state, action) => {
                state.currentChat.status = 'failed';
                state.currentChat.error = action.payload || action.error.message;
            });
    },
});

// 导出 actions
export const {
    resetOperationStatus,
    resetCurrentChat,
    setCurrentChat,
    resetMessages,
    resetSendMessageStatus,
    addMessage,
} = chatSlice.actions;

// 导出 reducer
export default chatSlice.reducer;
