import { createAsyncThunk } from '@reduxjs/toolkit';
import { get, post, put, del } from '../../services/api';
import { showNotification } from '../notification.slice';

/**
 * 获取聊天列表
 * @param {Object} params - 查询参数
 * @param {number} params.page - 页码
 * @param {number} params.page_size - 每页数量
 */
export const fetchChats = createAsyncThunk('chat/fetchChats', async (params = {}, { rejectWithValue }) => {
    try {
        const response = await get('/chat-history/', { params });

        // 处理返回格式
        if (response && response.code === 200) {
            return {
                results: response.data.results,
                total: response.data.total,
                page: response.data.page || 1,
                page_size: response.data.page_size || 10,
            };
        }

        return { results: [], total: 0, page: 1, page_size: 10 };
    } catch (error) {
        console.error('Error fetching chats:', error);
        return rejectWithValue(error.response?.data?.message || 'Failed to fetch chats');
    }
});

/**
 * 创建新聊天
 * @param {Object} chatData - 聊天数据
 * @param {string} chatData.knowledge_base_id - 知识库ID
 * @param {string} chatData.title - 聊天标题
 */
export const createChat = createAsyncThunk('chat/createChat', async (chatData, { rejectWithValue }) => {
    try {
        const response = await post('/chat-history/', chatData);

        // 处理返回格式
        if (response && response.code === 200) {
            return response.data.chat;
        }

        return response.data?.chat || {};
    } catch (error) {
        return rejectWithValue(error.response?.data || 'Failed to create chat');
    }
});

/**
 * 更新聊天
 * @param {Object} params - 更新参数
 * @param {string} params.id - 聊天ID
 * @param {Object} params.data - 更新数据
 */
export const updateChat = createAsyncThunk('chat/updateChat', async ({ id, data }, { rejectWithValue }) => {
    try {
        const response = await put(`/chat-history/${id}/`, data);

        // 处理返回格式
        if (response && response.code === 200) {
            return response.data.chat;
        }

        return response.data?.chat || {};
    } catch (error) {
        return rejectWithValue(error.response?.data || 'Failed to update chat');
    }
});

/**
 * 删除聊天
 * @param {string} conversationId - 聊天ID
 */
export const deleteChat = createAsyncThunk('chat/deleteChat', async (conversationId, { rejectWithValue }) => {
    try {
        const response = await del(`/chat-history/conversation/${conversationId}/`);

        // 处理返回格式
        if (response && response.code === 200) {
            return conversationId;
        }

        return conversationId;
    } catch (error) {
        console.error('Error deleting chat:', error);
        return rejectWithValue(error.response?.data?.message || '删除聊天失败');
    }
});

/**
 * 获取可用于聊天的知识库列表
 */
export const fetchAvailableDatasets = createAsyncThunk(
    'chat/fetchAvailableDatasets',
    async (_, { rejectWithValue }) => {
        try {
            const response = await get('/chat-history/available_datasets/');

            if (response && response.code === 200) {
                return response.data;
            }

            return rejectWithValue('获取可用知识库列表失败');
        } catch (error) {
            console.error('Error fetching available datasets:', error);
            return rejectWithValue(error.response?.data?.message || '获取可用知识库列表失败');
        }
    }
);

/**
 * 创建聊天记录
 * @param {Object} params - 聊天参数
 * @param {string[]} params.dataset_id_list - 知识库ID列表
 * @param {string} params.question - 用户问题
 * @param {string} params.conversation_id - 会话ID，可选
 */
export const createChatRecord = createAsyncThunk('chat/createChatRecord', async (params, { rejectWithValue }) => {
    try {
        const response = await post('/chat-history/', {
            dataset_id_list: params.dataset_id_list,
            question: params.question,
            conversation_id: params.conversation_id,
        });

        // 处理返回格式
        if (response && response.code === 200) {
            return response.data;
        }

        return rejectWithValue(response.message || '创建聊天记录失败');
    } catch (error) {
        console.error('Error creating chat record:', error);
        return rejectWithValue(error.response?.data?.message || '创建聊天记录失败');
    }
});

/**
 * 获取会话详情
 * @param {string} conversationId - 会话ID
 */
export const fetchConversationDetail = createAsyncThunk(
    'chat/fetchConversationDetail',
    async (conversationId, { rejectWithValue, dispatch }) => {
        try {
            const response = await get('/chat-history/conversation_detail', {
                params: { conversation_id: conversationId },
            });

            if (response && response.code === 200) {
                // 如果存在消息，更新Redux状态
                if (response.data.messages) {
                    dispatch({
                        type: 'chat/fetchMessages/fulfilled',
                        payload: response.data.messages,
                    });
                }

                return response.data;
            }

            return rejectWithValue('获取会话详情失败');
        } catch (error) {
            // 如果是新聊天，API会返回404，此时不返回错误
            if (error.response && error.response.status === 404) {
                return null;
            }

            console.error('Error fetching conversation detail:', error);
            return rejectWithValue(error.response?.data?.message || '获取会话详情失败');
        }
    }
);
